define(
//begin v1.x content
{
	"dayPeriods-format-narrow-noon": "midi",
	"dateFormatItem-yMd": "dd.MM.y",
	"dateFormatItem-MEd": "E, dd.MM.",
	"dateFormatItem-MMdd": "dd.MM",
	"dateFormatItem-yMEd": "E, dd.MM.y",
	"dayPeriods-format-narrow-night1": "du mat.",
	"timeFormat-full": "HH.mm:ss 'h' zzzz",
	"dateFormatItem-Md": "dd.MM.",
	"dayPeriods-format-abbr-midnight": "min.",
	"dayPeriods-format-abbr-morning1": "du mat.",
	"dayPeriods-format-abbr-night1": "du mat.",
	"dayPeriods-standAlone-abbr-midnight": "min.",
	"dayPeriods-format-abbr-afternoon1": "de l’ap.m.",
	"dayPeriods-format-abbr-evening1": "du soir",
	"dayPeriods-format-narrow-midnight": "min.",
	"dayPeriods-format-narrow-afternoon1": "de l’ap.m.",
	"dateFormat-short": "dd.MM.yy",
	"dayPeriods-standAlone-narrow-midnight": "min.",
	"dateFormatItem-yM": "MM.y",
	"dayPeriods-format-narrow-morning1": "du mat.",
	"dayPeriods-format-narrow-evening1": "du soir",
	"dayPeriods-format-abbr-noon": "midi",
	"dateFormat-full": "EEEE, d MMMM y"
}
//end v1.x content
);